@@ -1,8 +1,10 @@
+### R code from vignette source 'repeated.Rnw'
+
 ###################################################
-### chunk number 1: preliminaries
+### code chunk number 1: preliminaries
 ###################################################
 set.seed(1071)
-old.opts <- options(width=85, digits=6, useFancyQuotes = FALSE, continue="  ")
+old.opts <- options(width=85, digits=6, useFancyQuotes = FALSE, continue="  ", prompt="R> ")
 library(heplots)
 library(lattice)
 library(nlme)
@@ -13,13 +15,13 @@ if (car2 <- packageDescription("car")[["Version"]] >= 2) data.ellipse <- dataEll
 
 
 ###################################################
-### chunk number 2: voc0
+### code chunk number 2: voc0
 ###################################################
 some(VocabGrowth,5)
 
 
 ###################################################
-### chunk number 3: voc1
+### code chunk number 3: voc1
 ###################################################
 voc <- reshape(VocabGrowth, direction="long", varying=list(grade=1:4), timevar="Grade", v.names="Vocabulary")
 boxplot(Vocabulary ~ Grade, data=voc, col="bisque",
@@ -31,26 +33,26 @@ lines(1:4, means, col="blue", lwd=2)
 
 
 ###################################################
-### chunk number 4: voc2
+### code chunk number 4: voc2
 ###################################################
 (Vocab.mod <- lm(cbind(grade8,grade9,grade10,grade11) ~ 1, data=VocabGrowth))
 
 
 ###################################################
-### chunk number 5: voc3
+### code chunk number 5: voc3
 ###################################################
 (Vocab.aov0 <- Anova(Vocab.mod, type="III"))
 
 
 ###################################################
-### chunk number 6: voc-Anova
+### code chunk number 6: voc-Anova
 ###################################################
 Vocab.aov0$SSP     # H matrix
 Vocab.aov0$SSPE    # E matrix
 
 
 ###################################################
-### chunk number 7: markH0
+### code chunk number 7: markH0
 ###################################################
 mark.H0 <- function(x=0, y=0, cex=2, pch=19, col="green3", lty=2, pos=2) {
   points(x,y, cex=cex, col=col, pch=pch)
@@ -61,7 +63,7 @@ mark.H0 <- function(x=0, y=0, cex=2, pch=19, col="green3", lty=2, pos=2) {
 
 
 ###################################################
-### chunk number 8: voc4
+### code chunk number 8: voc4
 ###################################################
 heplot(Vocab.mod, terms="(Intercept)", type="III")
 mark.H0(0,0)
@@ -69,14 +71,14 @@ title(expression(paste("Multivariate test of ", H[0], " : ", bold(mu)==0)))
 
 
 ###################################################
-### chunk number 9: voc5
+### code chunk number 9: voc5
 ###################################################
 idata <-data.frame(grade=ordered(8:11))
 (Vocab.aov <- Anova(Vocab.mod, idata=idata, idesign=~grade, type="III"))
 
 
 ###################################################
-### chunk number 10: voc6
+### code chunk number 10: voc6
 ###################################################
 trends <- as.matrix(VocabGrowth) %*% poly(8:11, degree=3)
 colnames(trends)<- c("Linear", "Quad", "Cubic")
@@ -88,7 +90,7 @@ Anova(within.mod, type="III")
 
 
 ###################################################
-### chunk number 11: voc8
+### code chunk number 11: voc8
 ###################################################
 op <- par(mfrow=c(1,2))
 data.ellipse(trends[,1:2], xlim=c(-4,8), ylim=c(-3,3), levels=0.68,
@@ -103,9 +105,9 @@ par(op)
 
 
 ###################################################
-### chunk number 12: obk1
+### code chunk number 12: obk1
 ###################################################
-library(car)	# for OBrienKaiser data
+library("car")	# for OBrienKaiser data
 
 # simplified analysis of OBrienKaiser data, collapsing over hour
 OBK <- OBrienKaiser
@@ -117,20 +119,20 @@ OBK <- OBK[,-(3:17)]
 
 
 ###################################################
-### chunk number 13: obk2
+### code chunk number 13: obk2
 ###################################################
 table(OBK$gender, OBK$treatment)
 
 
 ###################################################
-### chunk number 14: obk3
+### code chunk number 14: obk3
 ###################################################
 contrasts(OBK$gender)
 contrasts(OBK$treatment)
 
 
 ###################################################
-### chunk number 15: obk-MANOVA
+### code chunk number 15: obk-MANOVA
 ###################################################
 # MANOVA model
 mod.OBK <- lm(cbind(pre, post, fup) ~  treatment*gender,  data=OBK)
@@ -138,7 +140,7 @@ mod.OBK
 
 
 ###################################################
-### chunk number 16: obk4
+### code chunk number 16: obk4
 ###################################################
 session <- ordered(c("pretest", "posttest", "followup"),
     levels=c("pretest", "posttest", "followup"))
@@ -149,7 +151,7 @@ idata <- data.frame(session)
 
 
 ###################################################
-### chunk number 17: obk4
+### code chunk number 17: obk4
 ###################################################
 # Multivariate tests for repeated measures
 aov.OBK <- Anova(mod.OBK, idata=idata, idesign=~session, test="Roy")
@@ -157,7 +159,7 @@ aov.OBK
 
 
 ###################################################
-### chunk number 18: obk5
+### code chunk number 18: obk5
 ###################################################
 # All multivariate tests
 summary(aov.OBK, univariate=FALSE)
@@ -166,19 +168,19 @@ summary(aov.OBK, multivariate=FALSE)
 
 
 ###################################################
-### chunk number 19: obk-HE1
+### code chunk number 19: obk-HE1
 ###################################################
 # HE plots for Between-S effects
 heplot(mod.OBK, hypotheses=c("treatment1", "treatment2"),
-	col=c("red", "black", "blue", "brown", "gray40", "gray40"),
-	hyp.labels=c("(A,B)-Control", "A-B"),
-	main="Between-S effects and contrasts"
+  col=c("red", "black", "blue", "brown", "gray40", "gray40"),
+  hyp.labels=c("(A,B)-Control", "A-B"),
+  main="Between-S effects and contrasts"
 	)
 lines(c(3,7), c(3,7), col="green")
 
 
 ###################################################
-### chunk number 20: obk-3d eval=FALSE
+### code chunk number 20: obk-3d (eval = FALSE)
 ###################################################
 ## heplot3d(mod.OBK, hypotheses=c("treatment1", "treatment2"),
 ## 	col=c("pink", "black", "blue", "brown", "gray40", "gray40"),
@@ -189,13 +191,13 @@ lines(c(3,7), c(3,7), col="green")
 
 
 ###################################################
-### chunk number 21: obk-HE2
+### code chunk number 21: obk-HE2
 ###################################################
 pairs(mod.OBK, col=c("red", "black", "blue", "brown"))
 
 
 ###################################################
-### chunk number 22: obk6
+### code chunk number 22: obk6
 ###################################################
 # Transform to profile contrasts for within-S effects
 OBK$session.1 <- OBK$post - OBK$pre
@@ -205,7 +207,7 @@ Anova(mod1.OBK, test="Roy", type="III")
 
 
 ###################################################
-### chunk number 23: obk-HE3
+### code chunk number 23: obk-HE3
 ###################################################
 # HE plots for Within-S effects
 heplot(mod1.OBK,
@@ -221,7 +223,7 @@ mark.H0(0,0)
 
 
 ###################################################
-### chunk number 24: obk2-1
+### code chunk number 24: obk2-1
 ###################################################
 session <- factor(rep(c("pretest", "posttest", "followup"), c(5, 5, 5)),
     levels=c("pretest", "posttest", "followup"))
@@ -232,14 +234,14 @@ within <- data.frame(session, hour)
 
 
 ###################################################
-### chunk number 25: obk2-2
+### code chunk number 25: obk2-2
 ###################################################
 str(within)
 within
 
 
 ###################################################
-### chunk number 26: obk2-3
+### code chunk number 26: obk2-3
 ###################################################
 mod.OBK2 <- lm(cbind(pre.1, pre.2, pre.3, pre.4, pre.5,
                      post.1, post.2, post.3, post.4, post.5,
@@ -249,7 +251,7 @@ mod.OBK2 <- lm(cbind(pre.1, pre.2, pre.3, pre.4, pre.5,
 
 
 ###################################################
-### chunk number 27: obk2-4
+### code chunk number 27: obk2-4
 ###################################################
 M.session <- matrix(c(-1,  1, 0,
                        0, -1, 1), ncol=2)
@@ -278,14 +280,14 @@ M.sh <- kronecker( M.session, M.hour, make.dimnames=TRUE)
 
 
 ###################################################
-### chunk number 28: obk2-5
+### code chunk number 28: obk2-5
 ###################################################
 Y.hour <- as.matrix(OBrienKaiser[,3:17]) %*% M.h
 mod.OBK2.hour <- lm(Y.hour ~  treatment*gender,  data=OBrienKaiser)
 
 
 ###################################################
-### chunk number 29: obk2-HE1
+### code chunk number 29: obk2-HE1
 ###################################################
 labels <- c("hour", paste(c("treatment","gender","treatment:gender"),":hour", sep=""))
 colors <- c("red", "black", "blue", "brown", "purple")
@@ -294,13 +296,13 @@ mark.H0()
 
 
 ###################################################
-### chunk number 30: obk2-HE2
+### code chunk number 30: obk2-HE2
 ###################################################
 pairs(mod.OBK2.hour, type="III", remove.intercept=FALSE, term.labels="hour", col=colors)
 
 
 ###################################################
-### chunk number 31: doubly
+### code chunk number 31: doubly
 ###################################################
 M.measure <- diag(2)
 rownames(M.measure)<- c("Y1", "Y2")
@@ -310,17 +312,17 @@ kronecker(cbind(1, M.session), M.measure, make.dimnames=TRUE)
 
 
 ###################################################
-### chunk number 32: wl1
+### code chunk number 32: wl1
 ###################################################
 table(WeightLoss$group)
 some(WeightLoss)
 
 
 ###################################################
-### chunk number 33: wl-means
+### code chunk number 33: wl-means
 ###################################################
 op <- par(mfrow=c(1,2))
-library(gplots)
+library("gplots")
 WLlong <-reshape(WeightLoss, varying=list(WeightLoss=2:4, SelfEsteem=5:7), direction="long",
 	timevar = "month",
 	v.names=c("WeightLoss", "SelfEsteem"))
@@ -345,20 +347,20 @@ par(op)
 
 
 ###################################################
-### chunk number 34: wl2
+### code chunk number 34: wl2
 ###################################################
 contrasts(WeightLoss$group) <- matrix(c(-2,1,1, 0, -1, 1),ncol=2)
 (wl.mod<-lm(cbind(wl1,wl2,wl3,se1,se2,se3)~group, data=WeightLoss))
 
 
 ###################################################
-### chunk number 35: wl3
+### code chunk number 35: wl3
 ###################################################
 Anova(wl.mod)
 
 
 ###################################################
-### chunk number 36: wl-HE1
+### code chunk number 36: wl-HE1
 ###################################################
 op <- par(mfrow=c(1,2))
 heplot(wl.mod, hypotheses=c("group1", "group2"),
@@ -369,7 +371,7 @@ par(op)
 
 
 ###################################################
-### chunk number 37: wl4
+### code chunk number 37: wl4
 ###################################################
 measure <- kronecker(diag(2), unit(3, 'M')/3, make.dimnames=TRUE)
 colnames(measure)<- c('WL', 'SE')
@@ -382,7 +384,7 @@ Anova(between.mod, test="Roy", type="III")
 
 
 ###################################################
-### chunk number 38: wl-HE2
+### code chunk number 38: wl-HE2
 ###################################################
 heplot(between.mod, hypotheses=c("group1", "group2"),
 	xlab="Weight Loss", ylab="Self Esteem",
@@ -391,7 +393,7 @@ heplot(between.mod, hypotheses=c("group1", "group2"),
 
 
 ###################################################
-### chunk number 39: wl5
+### code chunk number 39: wl5
 ###################################################
 month <- kronecker(diag(2), poly(1:3, degree=2), make.dimnames=TRUE)
 colnames(month)<- c('WL1', 'WL2', 'SE1', 'SE2')
@@ -402,7 +404,7 @@ Anova(within.mod, test="Roy", type="III")
 
 
 ###################################################
-### chunk number 40: wl-HE3
+### code chunk number 40: wl-HE3
 ###################################################
 op <- par(mfrow=c(1,2))
 heplot(within.mod, hypotheses=c("group1", "group2"), variables=c(1,3),
@@ -422,18 +424,18 @@ par(op)
 
 
 ###################################################
-### chunk number 41: voc-new1 eval=FALSE
+### code chunk number 41: voc-new1
 ###################################################
-## (Vocab.mod <- lm(cbind(grade8,grade9,grade10,grade11) ~ 1, data=VocabGrowth))
-## 
-## idata <-data.frame(grade=ordered(8:11))
-## 
-## heplot(Vocab.mod, type="III", idata=idata, idesign=~grade, iterm="grade",
-## 	main="HE plot for Grade effect")
+(Vocab.mod <- lm(cbind(grade8,grade9,grade10,grade11) ~ 1, data=VocabGrowth))
+
+idata <-data.frame(grade=ordered(8:11))
+
+heplot(Vocab.mod, type="III", idata=idata, idesign=~grade, iterm="grade",
+	main="HE plot for Grade effect")
 
 
 ###################################################
-### chunk number 42: obk-new0
+### code chunk number 42: obk-new0
 ###################################################
 mod.OBK <- lm(cbind(pre, post, fup) ~  treatment*gender,  data=OBK)
 session <- ordered(c("pretest", "posttest", "followup"),
@@ -443,16 +445,16 @@ contrasts(session) <- matrix(c(-1,  1, 0,
 
 
 ###################################################
-### chunk number 43: obk-new1 eval=FALSE
+### code chunk number 43: obk-new1
 ###################################################
-## idata <- data.frame(session)
-## heplot(mod.OBK, idata=idata, idesign=~session, iterm="session",
-##   col=c("red", "black", "blue", "brown"),
-##   main="Within-S effects: Session * (Treat*Gender)")
+idata <- data.frame(session)
+heplot(mod.OBK, idata=idata, idesign=~session, iterm="session",
+  col=c("red", "black", "blue", "brown"),
+  main="Within-S effects: Session * (Treat*Gender)")
 
 
 ###################################################
-### chunk number 44: obk-new2 eval=FALSE
+### code chunk number 44: obk-new2 (eval = FALSE)
 ###################################################
 ## mod.OBK2 <- lm(cbind(pre.1, pre.2, pre.3, pre.4, pre.5,
 ##                      post.1, post.2, post.3, post.4, post.5,
@@ -463,22 +465,22 @@ contrasts(session) <- matrix(c(-1,  1, 0,
 
 
 ###################################################
-### chunk number 45: ortho-xyplot1-code
+### code chunk number 45: ortho-xyplot1-code
 ###################################################
-library(nlme)    # for Orthodont data
-library(lattice)
+data("Orthodont", package="nlme")
+library("lattice")
 xyplot(distance ~ age|Sex, data=Orthodont, type='b', groups=Subject, pch=15:25,
     col=palette(), cex=1.3, main="Orthodont data")
 
 
 ###################################################
-### chunk number 46: ortho-xyplot1
+### code chunk number 46: ortho-xyplot1
 ###################################################
 print(trellis.last.object())
 
 
 ###################################################
-### chunk number 47: ortho-xyplot2-code
+### code chunk number 47: ortho-xyplot2-code
 ###################################################
 xyplot(distance ~ age | Sex, data = Orthodont, groups = Subject,
     main = "Pooled OLS and Individual linear regressions ~ age", type = c('g', 'r'),
@@ -489,13 +491,13 @@ xyplot(distance ~ age | Sex, data = Orthodont, groups = Subject,
 
 
 ###################################################
-### chunk number 48: ortho-xyplot2
+### code chunk number 48: ortho-xyplot2
 ###################################################
 plot(trellis.last.object())
 
 
 ###################################################
-### chunk number 49: Ortho.mix1
+### code chunk number 49: Ortho.mix1
 ###################################################
 Ortho <- Orthodont
 Ortho$year <- Ortho$age - 8  # make intercept = initial status
@@ -507,7 +509,7 @@ anova(Ortho.mix1)
 
 
 ###################################################
-### chunk number 50: Ortho.mix3
+### code chunk number 50: Ortho.mix3
 ###################################################
 Ortho.mix3 <- lme(distance ~ year*Sex + I(year^2) + I(year^3), data=Ortho,
 		random = ~ 1 + year | Subject, method="ML")
@@ -515,13 +517,13 @@ anova(Ortho.mix3)
 
 
 ###################################################
-### chunk number 51: Ortho.anova
+### code chunk number 51: Ortho.anova
 ###################################################
 anova(Ortho.mix1, Ortho.mix3)
 
 
 ###################################################
-### chunk number 52: Ortho-fm1-code
+### code chunk number 52: Ortho-fm1-code
 ###################################################
 grid <- expand.grid(year=0:6, Sex=c("Male", "Female"))
 grid$age <- grid$year+8  # plot vs. age
@@ -534,13 +536,13 @@ xyplot(distance ~ age, data=fm.mix1, groups=Sex, type="b",
 
 
 ###################################################
-### chunk number 53: Ortho-fm1
+### code chunk number 53: Ortho-fm1
 ###################################################
 plot(trellis.last.object())
 
 
 ###################################################
-### chunk number 54: Ortho-fm3
+### code chunk number 54: Ortho-fm3
 ###################################################
 fm.mix3 <-cbind(grid, distance = predict(Ortho.mix3, newdata = grid, level=0))
 print(xyplot(distance ~ age, data=fm.mix3, groups=Sex, type="b",
@@ -550,16 +552,16 @@ print(xyplot(distance ~ age, data=fm.mix3, groups=Sex, type="b",
 
 
 ###################################################
-### chunk number 55: ortho-prep
+### code chunk number 55: ortho-prep
 ###################################################
-library(nlme)
+library("nlme")
 Orthowide <- reshape(Orthodont, v.names="distance", idvar=c("Subject", "Sex"),
 	timevar="age", direction="wide")
 some(Orthowide, 4)
 
 
 ###################################################
-### chunk number 56: ortho-mlm
+### code chunk number 56: ortho-mlm
 ###################################################
 Ortho.mod <- lm(cbind(distance.8, distance.10, distance.12, distance.14) ~ Sex, data=Orthowide)
 
@@ -569,7 +571,7 @@ Ortho.aov
 
 
 ###################################################
-### chunk number 57: ortho-HE
+### code chunk number 57: ortho-HE
 ###################################################
 op <- par(mfrow=c(1,2))
 heplot(Ortho.mod, variables=c(1,4), asp=1, col=c("red", "blue"),
@@ -583,26 +585,26 @@ par(op)
 
 
 ###################################################
-### chunk number 58: ortho-pairs
+### code chunk number 58: ortho-pairs
 ###################################################
 pairs(Ortho.mod, idata=idata, idesign=~age, iterm="age", col=c("red", "blue", "brown"))
 
 
 ###################################################
-### chunk number 59: ortho-nonlin-HE
+### code chunk number 59: ortho-nonlin-HE
 ###################################################
 heplot(Ortho.mod, idata=idata, idesign=~age, iterm="age", col=c("red", "blue", "brown"),
 	variables=c(2,3), main="Orthodont data: Nonlinear Within-S effects")
 
 
 ###################################################
-### chunk number 60: ortho-lh1
+### code chunk number 60: ortho-lh1
 ###################################################
 linearHypothesis(Ortho.mod, hypothesis="SexFemale", idata=idata, idesign=~age, iterms="age", title="Sex:age effect")
 
 
 ###################################################
-### chunk number 61: ortho-lh2
+### code chunk number 61: ortho-lh2
 ###################################################
 linear <- idata
 contrasts(linear$age, 1) <- contrasts(linear$age)[,1]
@@ -613,7 +615,7 @@ print(linearHypothesis(Ortho.mod, hypothesis="SexFemale",
 
 
 ###################################################
-### chunk number 62: ortho-lh3
+### code chunk number 62: ortho-lh3
 ###################################################
 nonlin <- idata
 contrasts(nonlin$age, 2) <- contrasts(nonlin$age)[,2:3]
@@ -624,7 +626,7 @@ print(linearHypothesis(Ortho.mod, hypothesis="SexFemale",
 
 
 ###################################################
-### chunk number 63: tidyup
+### code chunk number 63: tidyup
 ###################################################
 options(old.opts )
 
